# Welcome to Scores!


## Documentation Layout

   - [ userguide.md ](userguide.md)  - Guide for users
   - [ contributing.md ](contributing.md)  - Guide for contributors and developers
   - [ data.md ](data.md)  - Overview of relevant data sets
   - [ api.md ](api.md)    - API Reference Docs
